@@ -21,3 +21,12 @@ class TestFunctionWithHttpApi(BaseTest):
         self.verify_get_request_response(base_url + "some/path", 200)
         self.verify_get_request_response(base_url + "something", 404)
         self.verify_get_request_response(base_url + "another/endpoint", 404)
+
+    def test_function_with_http_api_default_path(self):
+        self.create_and_verify_stack("combination/function_with_http_api_default_path")
+
+        stack_outputs = self.get_stack_outputs()
+        base_url = stack_outputs["ApiUrl"]
+        # The $default route catches requests that don't explicitly match other routes
+        self.verify_get_request_response(base_url, 200)
+        self.verify_get_request_response(base_url + "something", 200)
