@@ -1,62 +1,78 @@
 import json
 from re import match
-from functools import reduce
+from typing import Any, Dict, List, Optional
+
 from samtranslator.model import PropertyType, Resource
 from samtranslator.model.exceptions import InvalidResourceException
-from samtranslator.model.types import is_type, one_of, is_str, list_of
-from samtranslator.model.intrinsics import ref, fnSub
+from samtranslator.model.intrinsics import fnSub, ref
+from samtranslator.model.types import IS_DICT, IS_STR, is_type, list_of, one_of
+from samtranslator.schema.common import PassThrough
 from samtranslator.translator import logical_id_generator
 from samtranslator.translator.arn_generator import ArnGenerator
 from samtranslator.utils.py27hash_fix import Py27Dict, Py27UniStr
+from samtranslator.validator.value_validator import sam_expect
 
 
 class ApiGatewayRestApi(Resource):
     resource_type = "AWS::ApiGateway::RestApi"
     property_types = {
-        "Body": PropertyType(False, is_type(dict)),
-        "BodyS3Location": PropertyType(False, is_type(dict)),
-        "CloneFrom": PropertyType(False, is_str()),
-        "Description": PropertyType(False, is_str()),
+        "Body": PropertyType(False, IS_DICT),
+        "BodyS3Location": PropertyType(False, IS_DICT),
+        "CloneFrom": PropertyType(False, IS_STR),
+        "Description": PropertyType(False, IS_STR),
         "FailOnWarnings": PropertyType(False, is_type(bool)),
-        "Name": PropertyType(False, is_str()),
-        "Parameters": PropertyType(False, is_type(dict)),
-        "EndpointConfiguration": PropertyType(False, is_type(dict)),
+        "Name": PropertyType(False, IS_STR),
+        "Parameters": PropertyType(False, IS_DICT),
+        "EndpointConfiguration": PropertyType(False, IS_DICT),
         "BinaryMediaTypes": PropertyType(False, is_type(list)),
         "MinimumCompressionSize": PropertyType(False, is_type(int)),
-        "Mode": PropertyType(False, is_str()),
-        "ApiKeySourceType": PropertyType(False, is_str()),
+        "Mode": PropertyType(False, IS_STR),
+        "ApiKeySourceType": PropertyType(False, IS_STR),
     }
 
+    Body: Optional[Dict[str, Any]]
+    BodyS3Location: Optional[Dict[str, Any]]
+    CloneFrom: Optional[PassThrough]
+    Description: Optional[PassThrough]
+    FailOnWarnings: Optional[PassThrough]
+    Name: Optional[PassThrough]
+    Parameters: Optional[Dict[str, Any]]
+    EndpointConfiguration: Optional[Dict[str, Any]]
+    BinaryMediaTypes: Optional[List[Any]]
+    MinimumCompressionSize: Optional[PassThrough]
+    Mode: Optional[PassThrough]
+    ApiKeySourceType: Optional[PassThrough]
+
     runtime_attrs = {"rest_api_id": lambda self: ref(self.logical_id)}
 
 
 class ApiGatewayStage(Resource):
     resource_type = "AWS::ApiGateway::Stage"
     property_types = {
-        "AccessLogSetting": PropertyType(False, is_type(dict)),
+        "AccessLogSetting": PropertyType(False, IS_DICT),
         "CacheClusterEnabled": PropertyType(False, is_type(bool)),
-        "CacheClusterSize": PropertyType(False, is_str()),
-        "CanarySetting": PropertyType(False, is_type(dict)),
-        "ClientCertificateId": PropertyType(False, is_str()),
-        "DeploymentId": PropertyType(True, is_str()),
-        "Description": PropertyType(False, is_str()),
-        "RestApiId": PropertyType(True, is_str()),
-        "StageName": PropertyType(True, one_of(is_str(), is_type(dict))),
-        "Tags": PropertyType(False, list_of(is_type(dict))),
+        "CacheClusterSize": PropertyType(False, IS_STR),
+        "CanarySetting": PropertyType(False, IS_DICT),
+        "ClientCertificateId": PropertyType(False, IS_STR),
+        "DeploymentId": PropertyType(True, IS_STR),
+        "Description": PropertyType(False, IS_STR),
+        "RestApiId": PropertyType(True, IS_STR),
+        "StageName": PropertyType(True, one_of(IS_STR, IS_DICT)),
+        "Tags": PropertyType(False, list_of(IS_DICT)),
         "TracingEnabled": PropertyType(False, is_type(bool)),
-        "Variables": PropertyType(False, is_type(dict)),
+        "Variables": PropertyType(False, IS_DICT),
         "MethodSettings": PropertyType(False, is_type(list)),
     }
 
     runtime_attrs = {"stage_name": lambda self: ref(self.logical_id)}
 
-    def update_deployment_ref(self, deployment_logical_id):
+    def update_deployment_ref(self, deployment_logical_id):  # type: ignore[no-untyped-def]
         self.DeploymentId = ref(deployment_logical_id)
 
 
 class ApiGatewayAccount(Resource):
     resource_type = "AWS::ApiGateway::Account"
-    property_types = {"CloudWatchRoleArn": PropertyType(False, one_of(is_str(), is_type(dict)))}
+    property_types = {"CloudWatchRoleArn": PropertyType(False, one_of(IS_STR, IS_DICT))}
 
 
 class ApiGatewayDeployment(Resource):
@@ -64,15 +80,15 @@ class ApiGatewayDeployment(Resource):
 
     resource_type = "AWS::ApiGateway::Deployment"
     property_types = {
-        "Description": PropertyType(False, is_str()),
-        "RestApiId": PropertyType(True, is_str()),
-        "StageDescription": PropertyType(False, is_type(dict)),
-        "StageName": PropertyType(False, is_str()),
+        "Description": PropertyType(False, IS_STR),
+        "RestApiId": PropertyType(True, IS_STR),
+        "StageDescription": PropertyType(False, IS_DICT),
+        "StageName": PropertyType(False, IS_STR),
     }
 
     runtime_attrs = {"deployment_id": lambda self: ref(self.logical_id)}
 
-    def make_auto_deployable(
+    def make_auto_deployable(  # type: ignore[no-untyped-def]
         self, stage, openapi_version=None, swagger=None, domain=None, redeploy_restapi_parameters=None
     ):
         """
@@ -109,23 +125,30 @@ class ApiGatewayDeployment(Resource):
         data = self._X_HASH_DELIMITER.join(hash_input)
         generator = logical_id_generator.LogicalIdGenerator(self.logical_id, data)
         self.logical_id = generator.gen()
-        digest = generator.get_hash(length=40)  # Get the full hash
+        digest = generator.get_hash(length=40)
         self.Description = "RestApi deployment id: {}".format(digest)
         stage.update_deployment_ref(self.logical_id)
 
 
-class ApiGatewayResponse(object):
+class ApiGatewayResponse:
     ResponseParameterProperties = ["Headers", "Paths", "QueryStrings"]
 
-    def __init__(self, api_logical_id=None, response_parameters=None, response_templates=None, status_code=None):
+    def __init__(
+        self,
+        api_logical_id: str,
+        response_parameters: Optional[Dict[str, Any]] = None,
+        response_templates: Optional[PassThrough] = None,
+        status_code: Optional[str] = None,
+    ) -> None:
         if response_parameters:
+            # response_parameters has been validated in ApiGenerator._add_gateway_responses()
             for response_parameter_key in response_parameters.keys():
                 if response_parameter_key not in ApiGatewayResponse.ResponseParameterProperties:
                     raise InvalidResourceException(
                         api_logical_id, "Invalid gateway response parameter '{}'".format(response_parameter_key)
                     )
 
-        status_code_str = self._status_code_string(status_code)
+        status_code_str = self._status_code_string(status_code)  # type: ignore[no-untyped-call]
         # status_code must look like a status code, if present. Let's not be judgmental; just check 0-999.
         if status_code and not match(r"^[0-9]{1,3}$", status_code_str):
             raise InvalidResourceException(api_logical_id, "Property 'StatusCode' must be numeric")
@@ -136,10 +159,10 @@ class ApiGatewayResponse(object):
         self.response_templates = response_templates or Py27Dict()
         self.status_code = status_code_str
 
-    def generate_swagger(self):
+    def generate_swagger(self) -> Py27Dict:
         # Applying Py27Dict here as this goes into swagger
         swagger = Py27Dict()
-        swagger["responseParameters"] = self._add_prefixes(self.response_parameters)
+        swagger["responseParameters"] = self._add_prefixes(self.response_parameters)  # type: ignore[no-untyped-call]
         swagger["responseTemplates"] = self.response_templates
 
         # Prevent "null" being written.
@@ -148,14 +171,18 @@ class ApiGatewayResponse(object):
 
         return swagger
 
-    def _add_prefixes(self, response_parameters):
+    def _add_prefixes(self, response_parameters):  # type: ignore[no-untyped-def]
         GATEWAY_RESPONSE_PREFIX = "gatewayresponse."
         # applying Py27Dict as this is part of swagger
         prefixed_parameters = Py27Dict()
 
         parameter_prefix_pairs = [("Headers", "header."), ("Paths", "path."), ("QueryStrings", "querystring.")]
-        for parameter, prefix in parameter_prefix_pairs:
-            for key, value in response_parameters.get(parameter, {}).items():
+        for parameter_property_name, prefix in parameter_prefix_pairs:
+            parameter_property_value = response_parameters.get(parameter_property_name, {})
+            sam_expect(
+                parameter_property_value, self.api_logical_id, f"ResponseParameters.{parameter_property_name}"
+            ).to_be_a_map()
+            for key, value in parameter_property_value.items():
                 param_key = GATEWAY_RESPONSE_PREFIX + prefix + key
                 if isinstance(key, Py27UniStr):
                     # if key is from template, we need to convert param_key to Py27UniStr
@@ -164,30 +191,38 @@ class ApiGatewayResponse(object):
 
         return prefixed_parameters
 
-    def _status_code_string(self, status_code):
+    def _status_code_string(self, status_code):  # type: ignore[no-untyped-def]
         return None if status_code is None else str(status_code)
 
 
 class ApiGatewayDomainName(Resource):
     resource_type = "AWS::ApiGateway::DomainName"
     property_types = {
-        "RegionalCertificateArn": PropertyType(False, is_str()),
-        "DomainName": PropertyType(True, is_str()),
-        "EndpointConfiguration": PropertyType(False, is_type(dict)),
-        "MutualTlsAuthentication": PropertyType(False, is_type(dict)),
-        "SecurityPolicy": PropertyType(False, is_str()),
-        "CertificateArn": PropertyType(False, is_str()),
-        "OwnershipVerificationCertificateArn": PropertyType(False, is_str()),
+        "RegionalCertificateArn": PropertyType(False, IS_STR),
+        "DomainName": PropertyType(True, IS_STR),
+        "EndpointConfiguration": PropertyType(False, IS_DICT),
+        "MutualTlsAuthentication": PropertyType(False, IS_DICT),
+        "SecurityPolicy": PropertyType(False, IS_STR),
+        "CertificateArn": PropertyType(False, IS_STR),
+        "OwnershipVerificationCertificateArn": PropertyType(False, IS_STR),
     }
 
+    RegionalCertificateArn: Optional[PassThrough]
+    DomainName: PassThrough
+    EndpointConfiguration: Optional[PassThrough]
+    MutualTlsAuthentication: Optional[Dict[str, Any]]
+    SecurityPolicy: Optional[PassThrough]
+    CertificateArn: Optional[PassThrough]
+    OwnershipVerificationCertificateArn: Optional[PassThrough]
+
 
 class ApiGatewayBasePathMapping(Resource):
     resource_type = "AWS::ApiGateway::BasePathMapping"
     property_types = {
-        "BasePath": PropertyType(False, is_str()),
-        "DomainName": PropertyType(True, is_str()),
-        "RestApiId": PropertyType(False, is_str()),
-        "Stage": PropertyType(False, is_str()),
+        "BasePath": PropertyType(False, IS_STR),
+        "DomainName": PropertyType(True, IS_STR),
+        "RestApiId": PropertyType(False, IS_STR),
+        "Stage": PropertyType(False, IS_STR),
     }
 
 
@@ -195,11 +230,11 @@ class ApiGatewayUsagePlan(Resource):
     resource_type = "AWS::ApiGateway::UsagePlan"
     property_types = {
         "ApiStages": PropertyType(False, is_type(list)),
-        "Description": PropertyType(False, is_str()),
-        "Quota": PropertyType(False, is_type(dict)),
+        "Description": PropertyType(False, IS_STR),
+        "Quota": PropertyType(False, IS_DICT),
         "Tags": PropertyType(False, list_of(dict)),
-        "Throttle": PropertyType(False, is_type(dict)),
-        "UsagePlanName": PropertyType(False, is_str()),
+        "Throttle": PropertyType(False, IS_DICT),
+        "UsagePlanName": PropertyType(False, IS_STR),
     }
     runtime_attrs = {"usage_plan_id": lambda self: ref(self.logical_id)}
 
@@ -207,44 +242,55 @@ class ApiGatewayUsagePlan(Resource):
 class ApiGatewayUsagePlanKey(Resource):
     resource_type = "AWS::ApiGateway::UsagePlanKey"
     property_types = {
-        "KeyId": PropertyType(True, is_str()),
-        "KeyType": PropertyType(True, is_str()),
-        "UsagePlanId": PropertyType(True, is_str()),
+        "KeyId": PropertyType(True, IS_STR),
+        "KeyType": PropertyType(True, IS_STR),
+        "UsagePlanId": PropertyType(True, IS_STR),
     }
 
 
 class ApiGatewayApiKey(Resource):
     resource_type = "AWS::ApiGateway::ApiKey"
     property_types = {
-        "CustomerId": PropertyType(False, is_str()),
-        "Description": PropertyType(False, is_str()),
+        "CustomerId": PropertyType(False, IS_STR),
+        "Description": PropertyType(False, IS_STR),
         "Enabled": PropertyType(False, is_type(bool)),
         "GenerateDistinctId": PropertyType(False, is_type(bool)),
-        "Name": PropertyType(False, is_str()),
+        "Name": PropertyType(False, IS_STR),
         "StageKeys": PropertyType(False, is_type(list)),
-        "Value": PropertyType(False, is_str()),
+        "Value": PropertyType(False, IS_STR),
     }
 
     runtime_attrs = {"api_key_id": lambda self: ref(self.logical_id)}
 
 
-class ApiGatewayAuthorizer(object):
+class ApiGatewayAuthorizer:
     _VALID_FUNCTION_PAYLOAD_TYPES = [None, "TOKEN", "REQUEST"]
 
-    def __init__(
+    def __init__(  # type: ignore[no-untyped-def]
         self,
         api_logical_id=None,
         name=None,
         user_pool_arn=None,
         function_arn=None,
         identity=None,
-        function_payload_type=None,
+        function_payload_type: Optional[str] = None,
         function_invoke_role=None,
         is_aws_iam_authorizer=False,
         authorization_scopes=None,
     ):
         if authorization_scopes is None:
             authorization_scopes = []
+
+        self.api_logical_id = api_logical_id
+        self.name = name
+        self.user_pool_arn = user_pool_arn
+        self.function_arn = function_arn
+        self.identity = identity
+        self.function_payload_type = function_payload_type
+        self.function_invoke_role = function_invoke_role
+        self.is_aws_iam_authorizer = is_aws_iam_authorizer
+        self.authorization_scopes = authorization_scopes
+
         if function_payload_type not in ApiGatewayAuthorizer._VALID_FUNCTION_PAYLOAD_TYPES:
             raise InvalidResourceException(
                 api_logical_id,
@@ -261,20 +307,12 @@ class ApiGatewayAuthorizer(object):
         if authorization_scopes is not None and not isinstance(authorization_scopes, list):
             raise InvalidResourceException(api_logical_id, "AuthorizationScopes must be a list.")
 
-        self.api_logical_id = api_logical_id
-        self.name = name
-        self.user_pool_arn = user_pool_arn
-        self.function_arn = function_arn
-        self.identity = identity
-        self.function_payload_type = function_payload_type
-        self.function_invoke_role = function_invoke_role
-        self.is_aws_iam_authorizer = is_aws_iam_authorizer
-        self.authorization_scopes = authorization_scopes
-
-    def _is_missing_identity_source(self, identity):
+    def _is_missing_identity_source(self, identity: Dict[str, Any]) -> bool:
         if not identity:
             return True
 
+        sam_expect(identity, self.api_logical_id, f"Authorizer.{self.name}.Identity").to_be_a_map()
+
         headers = identity.get("Headers")
         query_strings = identity.get("QueryStrings")
         stage_variables = identity.get("StageVariables")
@@ -283,9 +321,11 @@ class ApiGatewayAuthorizer(object):
 
         required_properties_missing = not headers and not query_strings and not stage_variables and not context
 
+        if ttl is None:
+            return required_properties_missing
         try:
             ttl_int = int(ttl)
-        # this will catch if ttl is None and not convertable to an int
+        # this will catch if and not convertable to an int
         except (TypeError, ValueError):
             # previous behavior before trying to read ttl
             return required_properties_missing
@@ -293,7 +333,7 @@ class ApiGatewayAuthorizer(object):
         # If we can resolve ttl, attempt to see if things are valid
         return ttl_int > 0 and required_properties_missing
 
-    def generate_swagger(self):
+    def generate_swagger(self) -> Py27Dict:
         authorizer_type = self._get_type()
         APIGATEWAY_AUTHORIZER_KEY = "x-amazon-apigateway-authorizer"
         swagger = Py27Dict()
@@ -313,7 +353,7 @@ class ApiGatewayAuthorizer(object):
             partition = ArnGenerator.get_partition_name()
             resource = "lambda:path/2015-03-31/functions/${__FunctionArn__}/invocations"
             authorizer_uri = fnSub(
-                ArnGenerator.generate_arn(
+                ArnGenerator.generate_arn(  # type: ignore[no-untyped-call]
                     partition=partition, service="apigateway", resource=resource, include_account_id=False
                 ),
                 {"__FunctionArn__": self.function_arn},
@@ -345,24 +385,28 @@ class ApiGatewayAuthorizer(object):
 
         return swagger
 
-    def _get_identity_validation_expression(self):
+    def _get_identity_validation_expression(self) -> Optional[PassThrough]:
         return self.identity and self.identity.get("ValidationExpression")
 
-    def _build_identity_source_item(self, item_prefix, prop_value):
+    @staticmethod
+    def _build_identity_source_item(item_prefix: str, prop_value: str) -> str:
         item = item_prefix + prop_value
         if isinstance(prop_value, Py27UniStr):
             item = Py27UniStr(item)
         return item
 
-    def _build_identity_source_item_array(self, prop_key, item_prefix):
-        arr = []
-        if self.identity.get(prop_key):
-            arr = [
-                self._build_identity_source_item(item_prefix, prop_value) for prop_value in self.identity.get(prop_key)
-            ]
+    def _build_identity_source_item_array(self, prop_key: str, item_prefix: str) -> List[str]:
+        arr: List[str] = []
+        prop_value_list = self.identity.get(prop_key)
+        if prop_value_list:
+            prop_path = f"Auth.Authorizers.{self.name}.Identity.{prop_key}"
+            sam_expect(prop_value_list, self.api_logical_id, prop_path).to_be_a_list()
+            for index, prop_value in enumerate(prop_value_list):
+                sam_expect(prop_value, self.api_logical_id, f"{prop_path}[{index}]").to_be_a_string()
+                arr.append(self._build_identity_source_item(item_prefix, prop_value))
         return arr
 
-    def _get_identity_source(self):
+    def _get_identity_source(self) -> str:
         key_prefix_pairs = [
             ("Headers", "method.request.header."),
             ("QueryStrings", "method.request.querystring."),
@@ -370,12 +414,9 @@ class ApiGatewayAuthorizer(object):
             ("Context", "context."),
         ]
 
-        identity_source_array = reduce(
-            lambda accumulator, key_prefix_pair: accumulator
-            + self._build_identity_source_item_array(key_prefix_pair[0], key_prefix_pair[1]),
-            key_prefix_pairs,
-            [],
-        )
+        identity_source_array = []
+        for prop_key, item_prefix in key_prefix_pairs:
+            identity_source_array.extend(self._build_identity_source_item_array(prop_key, item_prefix))
 
         identity_source = ", ".join(identity_source_array)
         if any(isinstance(i, Py27UniStr) for i in identity_source_array):
@@ -384,10 +425,10 @@ class ApiGatewayAuthorizer(object):
 
         return identity_source
 
-    def _get_user_pool_arn_array(self):
+    def _get_user_pool_arn_array(self) -> List[PassThrough]:
         return self.user_pool_arn if isinstance(self.user_pool_arn, list) else [self.user_pool_arn]
 
-    def _get_swagger_header_name(self):
+    def _get_swagger_header_name(self) -> Optional[str]:
         authorizer_type = self._get_type()
         payload_type = self._get_function_payload_type()
 
@@ -396,7 +437,7 @@ class ApiGatewayAuthorizer(object):
 
         return self._get_identity_header()
 
-    def _get_type(self):
+    def _get_type(self) -> str:
         if self.is_aws_iam_authorizer:
             return "AWS_IAM"
 
@@ -405,7 +446,7 @@ class ApiGatewayAuthorizer(object):
 
         return "LAMBDA"
 
-    def _get_identity_header(self):
+    def _get_identity_header(self) -> Optional[str]:
         if self.identity and not isinstance(self.identity, dict):
             raise InvalidResourceException(
                 self.api_logical_id,
@@ -418,19 +459,19 @@ class ApiGatewayAuthorizer(object):
 
         return self.identity.get("Header")
 
-    def _get_reauthorize_every(self):
+    def _get_reauthorize_every(self) -> Optional[PassThrough]:
         if not self.identity:
             return None
 
         return self.identity.get("ReauthorizeEvery")
 
-    def _get_function_invoke_role(self):
+    def _get_function_invoke_role(self) -> Optional[PassThrough]:
         if not self.function_invoke_role or self.function_invoke_role == "NONE":
             return None
 
         return self.function_invoke_role
 
-    def _get_swagger_authtype(self):
+    def _get_swagger_authtype(self) -> str:
         authorizer_type = self._get_type()
         if authorizer_type == "AWS_IAM":
             return "awsSigv4"
@@ -440,10 +481,10 @@ class ApiGatewayAuthorizer(object):
 
         return "custom"
 
-    def _get_function_payload_type(self):
+    def _get_function_payload_type(self) -> str:
         return "TOKEN" if not self.function_payload_type else self.function_payload_type
 
-    def _get_swagger_authorizer_type(self):
+    def _get_swagger_authorizer_type(self) -> Optional[str]:
         authorizer_type = self._get_type()
 
         if authorizer_type == "COGNITO_USER_POOLS":
@@ -456,3 +497,5 @@ class ApiGatewayAuthorizer(object):
 
         if payload_type == "TOKEN":
             return "token"
+
+        return None  # should we raise validation error here?
