@@ -1,6 +1,8 @@
 import logging
+from abc import ABC
 
 from enum import Enum
+from typing import Optional
 
 LOG = logging.getLogger(__name__)
 
@@ -15,23 +17,34 @@ class LifeCycleEvents(Enum):
     after_transform_template = "after_transform_template"
 
 
-class BasePlugin(object):
+class BasePlugin(ABC):
     """
     Base class for a NoOp plugin that implements all available hooks
     """
 
-    def __init__(self, name):
+    _custom_name: Optional[str]
+
+    def __init__(self, name: Optional[str] = None) -> None:
         """
-        Initialize the plugin with given name. Name is always required to register a plugin
+        Initialize the plugin with optional given name.
 
-        :param name: Name of this plugin.
+        The optional name argument is for compatibility purpose.
+        In SAM-T codebase all plugins use the default name (class name).
+        :param name: Custom name of this plugin.
         """
-        if not name:
-            raise ValueError("'name' is required to create a plugin")
+        self._custom_name = name
 
-        self.name = name
+    @classmethod
+    def _class_name(cls) -> str:
+        return cls.__name__
 
-    def on_before_transform_resource(self, logical_id, resource_type, resource_properties):
+    @property
+    def name(self) -> str:
+        if self._custom_name:
+            return self._custom_name
+        return self._class_name()
+
+    def on_before_transform_resource(self, logical_id, resource_type, resource_properties):  # type: ignore[no-untyped-def]
         """
         Hook method to execute on `before_transform_resource` life cycle event. Plugins are free to modify the
         whole template or properties of the resource.
@@ -54,9 +67,8 @@ class BasePlugin(object):
 
         # Plugins can choose to skip implementing certain hook methods. In which case we will default to a
         # NoOp implementation
-        pass
 
-    def on_before_transform_template(self, template):
+    def on_before_transform_template(self, template_dict):  # type: ignore[no-untyped-def]
         """
         Hook method to execute on "before_transform_template" life cycle event. Plugins are free to modify the
         whole template, inject new resources, or modify certain sections of the template.
@@ -72,9 +84,8 @@ class BasePlugin(object):
         :return: nothing
         :raises InvalidDocumentException: If the hook decides that the SAM template is invalid.
         """
-        pass
 
-    def on_after_transform_template(self, template):
+    def on_after_transform_template(self, template):  # type: ignore[no-untyped-def]
         """
         Hook method to execute on "after_transform_template" life cycle event. Plugins may further modify
         the template. Warning: any changes made in this lifecycle action by a plugin will not be
@@ -89,4 +100,3 @@ class BasePlugin(object):
         :raises InvalidDocumentException: If the hook decides that the SAM template is invalid.
         :raises InvalidResourceException: If the hook decides that a SAM resource is invalid.
         """
-        pass
