@@ -1,8 +1,9 @@
 import copy
+from typing import TYPE_CHECKING
 
 from samtranslator.metrics.method_decorator import MetricsMethodWrapperSingleton
 from samtranslator.metrics.metrics import DummyMetricsPublisher, Metrics
-
+from typing import Dict, Any, Optional, List, Tuple
 from samtranslator.feature_toggle.feature_toggle import (
     FeatureToggle,
     FeatureToggleDefaultConfigProvider,
@@ -31,6 +32,9 @@ from samtranslator.policy_template_processor.processor import PolicyTemplatesPro
 from samtranslator.sdk.parameter import SamParameterValues
 from samtranslator.translator.arn_generator import ArnGenerator
 from samtranslator.model.eventsources.push import Api
+from samtranslator.model.sam_resources import SamConnector
+from samtranslator.validator.value_validator import sam_expect
+from samtranslator.model import Resource
 
 
 class Translator:
@@ -49,13 +53,16 @@ class Translator:
         self.feature_toggle = None
         self.boto_session = boto_session
         self.metrics = metrics if metrics else Metrics("ServerlessTransform", DummyMetricsPublisher())  # type: ignore[no-untyped-call, no-untyped-call]
-        MetricsMethodWrapperSingleton.set_instance(self.metrics)  # type: ignore[no-untyped-call]
+        MetricsMethodWrapperSingleton.set_instance(self.metrics)
         self._translated_resouce_mapping = {}
+        self.document_errors = []
 
         if self.boto_session:
             ArnGenerator.BOTO_SESSION_REGION_NAME = self.boto_session.region_name
 
-    def _get_function_names(self, resource_dict, intrinsics_resolver):  # type: ignore[no-untyped-def]
+    def _get_function_names(
+        self, resource_dict: Dict[str, Any], intrinsics_resolver: IntrinsicsResolver
+    ) -> Dict[str, str]:
         """
         :param resource_dict: AWS::Serverless::Function resource is provided as input
         :param intrinsics_resolver: to resolve intrinsics for function_name
@@ -71,19 +78,26 @@ class Translator:
                 item_properties = item.get("Properties", {})
                 if item.get("Type") == "Api" and item_properties.get("RestApiId"):
                     rest_api = item_properties.get("RestApiId")
-                    api_name = Api.get_rest_api_id_string(rest_api)  # type: ignore[no-untyped-call]
-                    if isinstance(api_name, str):
-                        resource_dict_copy = copy.deepcopy(resource_dict)
-                        function_name = intrinsics_resolver.resolve_parameter_refs(
-                            resource_dict_copy.get("Properties").get("FunctionName")
-                        )
-                        if function_name:
-                            self.function_names[api_name] = str(self.function_names.get(api_name, "")) + str(
-                                function_name
-                            )
+                    api_name = Api.get_rest_api_id_string(rest_api)
+                    if not isinstance(api_name, str):
+                        continue
+                    raw_function_name = resource_dict.get("Properties", {}).get("FunctionName")
+                    resolved_function_name = intrinsics_resolver.resolve_parameter_refs(
+                        copy.deepcopy(raw_function_name)
+                    )
+                    if not resolved_function_name:
+                        continue
+                    self.function_names.setdefault(api_name, "")
+                    self.function_names[api_name] += str(resolved_function_name)
         return self.function_names
 
-    def translate(self, sam_template, parameter_values, feature_toggle=None, passthrough_metadata=False):  # type: ignore[no-untyped-def]
+    def translate(
+        self,
+        sam_template: Dict[str, Any],
+        parameter_values: Dict[Any, Any],
+        feature_toggle: Optional[FeatureToggle] = None,
+        passthrough_metadata: Optional[bool] = False,
+    ) -> Dict[str, Any]:
         """Loads the SAM resources from the given SAM manifest, replaces them with their corresponding
         CloudFormation resources, and returns the resulting CloudFormation template.
 
@@ -103,37 +117,43 @@ class Translator:
             if feature_toggle
             else FeatureToggle(FeatureToggleDefaultConfigProvider(), stage=None, account_id=None, region=None)  # type: ignore[no-untyped-call, no-untyped-call]
         )
-        self.function_names = {}
+        self.function_names: Dict[Any, Any] = {}
         self.redeploy_restapi_parameters = {}
-        sam_parameter_values = SamParameterValues(parameter_values)  # type: ignore[no-untyped-call]
-        sam_parameter_values.add_default_parameter_values(sam_template)  # type: ignore[no-untyped-call]
+        sam_parameter_values = SamParameterValues(parameter_values)
+        sam_parameter_values.add_default_parameter_values(sam_template)
         sam_parameter_values.add_pseudo_parameter_values(self.boto_session)  # type: ignore[no-untyped-call]
         parameter_values = sam_parameter_values.parameter_values
         # Create & Install plugins
-        sam_plugins = prepare_plugins(self.plugins, parameter_values)  # type: ignore[no-untyped-call]
+        sam_plugins = prepare_plugins(self.plugins, parameter_values)
 
         self.sam_parser.parse(sam_template=sam_template, parameter_values=parameter_values, sam_plugins=sam_plugins)
 
+        # replaces Connectors attributes with serverless Connector resources
+        resources = sam_template.get("Resources", {})
+        embedded_connectors = self._get_embedded_connectors(resources)
+        connector_resources = self._update_resources(embedded_connectors)
+        resources.update(connector_resources)
+        self._delete_connectors_attribute(resources)
+
         template = copy.deepcopy(sam_template)
-        macro_resolver = ResourceTypeResolver(sam_resources)  # type: ignore[no-untyped-call]
-        intrinsics_resolver = IntrinsicsResolver(parameter_values)  # type: ignore[no-untyped-call]
+        macro_resolver = ResourceTypeResolver(sam_resources)
+        intrinsics_resolver = IntrinsicsResolver(parameter_values)
 
         # ResourceResolver is used by connector, its "resources" will be
         # updated in-place by other transforms so connector transform
         # can see the transformed resources.
         resource_resolver = ResourceResolver(template.get("Resources", {}))
-        mappings_resolver = IntrinsicsResolver(  # type: ignore[no-untyped-call]
+        mappings_resolver = IntrinsicsResolver(
             template.get("Mappings", {}), {FindInMapAction.intrinsic_name: FindInMapAction()}
         )
         deployment_preference_collection = DeploymentPreferenceCollection()
         supported_resource_refs = SupportedResourceReferences()
         shared_api_usage_plan = SharedApiUsagePlan()
-        document_errors = []
         changed_logical_ids = {}
-        route53_record_set_groups = {}  # type: ignore[var-annotated]
-        for logical_id, resource_dict in self._get_resources_to_iterate(sam_template, macro_resolver):  # type: ignore[no-untyped-call]
+        route53_record_set_groups: Dict[Any, Any] = {}
+        for logical_id, resource_dict in self._get_resources_to_iterate(sam_template, macro_resolver):
             try:
-                macro = macro_resolver.resolve_resource_type(resource_dict).from_dict(  # type: ignore[no-untyped-call]
+                macro = macro_resolver.resolve_resource_type(resource_dict).from_dict(
                     logical_id, resource_dict, sam_plugins=sam_plugins
                 )
 
@@ -146,7 +166,7 @@ class Translator:
                 kwargs["resource_resolver"] = resource_resolver
                 kwargs["original_template"] = sam_template
                 # add the value of FunctionName property if the function is referenced with the api resource
-                self.redeploy_restapi_parameters["function_names"] = self._get_function_names(  # type: ignore[no-untyped-call]
+                self.redeploy_restapi_parameters["function_names"] = self._get_function_names(
                     resource_dict, intrinsics_resolver
                 )
                 kwargs["redeploy_restapi_parameters"] = self.redeploy_restapi_parameters
@@ -162,7 +182,7 @@ class Translator:
 
                 del template["Resources"][logical_id]
                 for resource in translated:
-                    if verify_unique_logical_id(resource, sam_template["Resources"]):  # type: ignore[no-untyped-call]
+                    if verify_unique_logical_id(resource, sam_template["Resources"]):
                         # For each generated resource, pass through existing metadata that may exist on the original SAM resource.
                         _r = resource.to_dict()
                         if resource_dict.get("Metadata") and passthrough_metadata:
@@ -170,48 +190,50 @@ class Translator:
                                 _r[resource.logical_id]["Metadata"] = resource_dict["Metadata"]
                         template["Resources"].update(_r)
                     else:
-                        document_errors.append(
-                            DuplicateLogicalIdException(logical_id, resource.logical_id, resource.resource_type)  # type: ignore[no-untyped-call]
+                        self.document_errors.append(
+                            DuplicateLogicalIdException(logical_id, resource.logical_id, resource.resource_type)
                         )
             except (InvalidResourceException, InvalidEventException, InvalidTemplateException) as e:
-                document_errors.append(e)  # type: ignore[arg-type]
+                self.document_errors.append(e)
 
-        if deployment_preference_collection.any_enabled():  # type: ignore[no-untyped-call]
-            template["Resources"].update(deployment_preference_collection.get_codedeploy_application().to_dict())  # type: ignore[no-untyped-call]
-            if deployment_preference_collection.needs_resource_condition():  # type: ignore[no-untyped-call]
-                new_conditions = deployment_preference_collection.create_aggregate_deployment_condition()  # type: ignore[no-untyped-call]
+        if deployment_preference_collection.any_enabled():
+            template["Resources"].update(deployment_preference_collection.get_codedeploy_application().to_dict())
+            if deployment_preference_collection.needs_resource_condition():
+                new_conditions = deployment_preference_collection.create_aggregate_deployment_condition()
                 if new_conditions:
-                    template.get("Conditions").update(new_conditions)
+                    template.get("Conditions", {}).update(new_conditions)
 
-            if not deployment_preference_collection.can_skip_service_role():  # type: ignore[no-untyped-call]
-                template["Resources"].update(deployment_preference_collection.get_codedeploy_iam_role().to_dict())  # type: ignore[no-untyped-call]
+            if not deployment_preference_collection.can_skip_service_role():
+                template["Resources"].update(deployment_preference_collection.get_codedeploy_iam_role().to_dict())
 
-            for logical_id in deployment_preference_collection.enabled_logical_ids():  # type: ignore[no-untyped-call]
+            for logical_id in deployment_preference_collection.enabled_logical_ids():
                 try:
                     template["Resources"].update(
-                        deployment_preference_collection.deployment_group(logical_id).to_dict()  # type: ignore[no-untyped-call]
+                        deployment_preference_collection.deployment_group(logical_id).to_dict()
                     )
                 except InvalidResourceException as e:
-                    document_errors.append(e)  # type: ignore[arg-type]
+                    self.document_errors.append(e)
 
         # Run the after-transform plugin target
         try:
             sam_plugins.act(LifeCycleEvents.after_transform_template, template)
         except (InvalidDocumentException, InvalidResourceException, InvalidTemplateException) as e:
-            document_errors.append(e)  # type: ignore[arg-type]
+            self.document_errors.append(e)
 
         # Cleanup
         if "Transform" in template:
             del template["Transform"]
 
-        if len(document_errors) == 0:
-            template = intrinsics_resolver.resolve_sam_resource_id_refs(template, changed_logical_ids)  # type: ignore[no-untyped-call]
-            template = intrinsics_resolver.resolve_sam_resource_refs(template, supported_resource_refs)  # type: ignore[no-untyped-call]
+        if len(self.document_errors) == 0:
+            template = intrinsics_resolver.resolve_sam_resource_id_refs(template, changed_logical_ids)
+            template = intrinsics_resolver.resolve_sam_resource_refs(template, supported_resource_refs)
             return template
-        raise InvalidDocumentException(document_errors)
+        raise InvalidDocumentException(self.document_errors)
 
     # private methods
-    def _get_resources_to_iterate(self, sam_template, macro_resolver):  # type: ignore[no-untyped-def]
+    def _get_resources_to_iterate(
+        self, sam_template: Dict[str, Any], macro_resolver: ResourceTypeResolver
+    ) -> List[Tuple[str, Dict[str, Any]]]:
         """
         Returns a list of resources to iterate, order them based on the following order:
 
@@ -256,8 +278,107 @@ class Translator:
 
         return functions + statemachines + apis + others + connectors
 
+    @staticmethod
+    def _update_resources(connectors_list: List[Resource]) -> Dict[str, Any]:
+        connector_resources = {}
+        for connector in connectors_list:
+            connector_resources.update(connector.to_dict())
+        return connector_resources
 
-def prepare_plugins(plugins, parameters=None):  # type: ignore[no-untyped-def]
+    @staticmethod
+    def _delete_connectors_attribute(resources: Dict[str, Any]) -> None:
+        for resource in resources.values():
+            if "Connectors" not in resource:
+                continue
+            del resource["Connectors"]
+
+    def _get_embedded_connectors(self, resources: Dict[str, Any]) -> List[Resource]:
+        """
+        Loops through the SAM Template resources to find any connectors that have been attached to the resources.
+        Converts those attached connectors into Connector resources and returns a list of them
+
+        :param dict resources: Dict of resources from the SAM template
+        :return List[SamConnector]: List of the generated SAM Connectors
+        """
+        connectors = []
+
+        # Loop through the resources in the template and see if any connectors have been attached
+        for source_logical_id, resource in resources.items():
+            if "Connectors" not in resource:
+                continue
+            try:
+                sam_expect(
+                    resource.get("Connectors"),
+                    source_logical_id,
+                    f"{source_logical_id}.Connectors",
+                    is_resource_attribute=True,
+                ).to_be_a_map()
+            except InvalidResourceException as e:
+                self.document_errors.append(e)
+
+            for connector_logical_id, connector_dict in resource["Connectors"].items():
+                try:
+                    connector_logical_id = source_logical_id + connector_logical_id
+                    # can't use sam_expect since this is neither a property nor a resource attribute
+                    if not isinstance(connector_dict, dict):
+                        raise InvalidResourceException(
+                            connector_logical_id, f"{source_logical_id}.{connector_logical_id} should be a map."
+                        )
+
+                    generated_connector = self._get_generated_connector(
+                        source_logical_id,
+                        connector_logical_id,
+                        connector_dict,
+                    )
+
+                    if not verify_unique_logical_id(generated_connector, resources):
+                        raise DuplicateLogicalIdException(
+                            source_logical_id, connector_logical_id, generated_connector.resource_type
+                        )
+                    connectors.append(generated_connector)
+                except (InvalidResourceException, DuplicateLogicalIdException) as e:
+                    self.document_errors.append(e)
+
+        return connectors
+
+    def _get_generated_connector(
+        self, source_logical_id: str, connector_logical_id: str, connector_dict: Dict[str, Any]
+    ) -> Resource:
+        """
+        Generates the connector resource from the embedded connector
+
+        :param str source_logical_id: Logical id of the resource the connector is attached to
+        :param str connector_logical_id: Logical id of the connector
+        :param dict connector_dict: The properties of the connector including the Destination, Permissions and optionally the SourceReference
+        :return: The generated SAMConnector resource
+        """
+        connector = copy.deepcopy(connector_dict)
+        connector["Type"] = SamConnector.resource_type
+
+        # No need to raise an error for this instance as the error will be caught by the parser
+        if "Properties" in connector_dict and isinstance(connector_dict["Properties"], dict):
+            properties = connector["Properties"]
+            properties["Source"] = {"Id": source_logical_id}
+            if "SourceReference" in properties:
+                sam_expect(
+                    properties.get("SourceReference"),
+                    connector_logical_id,
+                    f"{connector_logical_id}.Properties.SourceReference",
+                ).to_be_a_map()
+
+                # can't allow user to override the Id using SourceReference
+                if "Id" in properties["SourceReference"]:
+                    raise InvalidResourceException(
+                        connector_logical_id, "'Id' shouldn't be defined in 'SourceReference'."
+                    )
+
+                properties["Source"].update(properties["SourceReference"])
+                del properties["SourceReference"]
+
+        return SamConnector.from_dict(connector_logical_id, connector)
+
+
+def prepare_plugins(plugins: List[Any], parameters: Optional[Dict[str, Any]] = None) -> SamPlugins:
     """
     Creates & returns a plugins object with the given list of plugins installed. In addition to the given plugins,
     we will also install a few "required" plugins that are necessary to provide complete support for SAM template spec.
@@ -271,10 +392,10 @@ def prepare_plugins(plugins, parameters=None):  # type: ignore[no-untyped-def]
         parameters = {}
     required_plugins = [
         DefaultDefinitionBodyPlugin(),
-        make_implicit_rest_api_plugin(),  # type: ignore[no-untyped-call]
-        make_implicit_http_api_plugin(),  # type: ignore[no-untyped-call]
+        make_implicit_rest_api_plugin(),
+        make_implicit_http_api_plugin(),
         GlobalsPlugin(),
-        make_policy_template_for_function_plugin(),  # type: ignore[no-untyped-call]
+        make_policy_template_for_function_plugin(),
     ]
 
     plugins = [] if not plugins else plugins
@@ -285,30 +406,35 @@ def prepare_plugins(plugins, parameters=None):  # type: ignore[no-untyped-def]
 
     # Execute customer's plugins first before running SAM plugins. It is very important to retain this order because
     # other plugins will be dependent on this ordering.
-    return SamPlugins(plugins + required_plugins)  # type: ignore[no-untyped-call]
+    return SamPlugins(plugins + required_plugins)
 
 
-def make_implicit_rest_api_plugin():  # type: ignore[no-untyped-def]
+if TYPE_CHECKING:
+    from samtranslator.plugins.api.implicit_rest_api_plugin import ImplicitRestApiPlugin
+    from samtranslator.plugins.api.implicit_http_api_plugin import ImplicitHttpApiPlugin
+
+
+def make_implicit_rest_api_plugin() -> "ImplicitRestApiPlugin":
     # This is necessary to prevent a circular dependency on imports when loading package
     from samtranslator.plugins.api.implicit_rest_api_plugin import ImplicitRestApiPlugin
 
     return ImplicitRestApiPlugin()
 
 
-def make_implicit_http_api_plugin():  # type: ignore[no-untyped-def]
+def make_implicit_http_api_plugin() -> "ImplicitHttpApiPlugin":
     # This is necessary to prevent a circular dependency on imports when loading package
     from samtranslator.plugins.api.implicit_http_api_plugin import ImplicitHttpApiPlugin
 
     return ImplicitHttpApiPlugin()
 
 
-def make_policy_template_for_function_plugin():  # type: ignore[no-untyped-def]
+def make_policy_template_for_function_plugin() -> PolicyTemplatesForResourcePlugin:
     """
     Constructs an instance of policy templates processing plugin using default policy templates JSON data
 
     :return plugins.policies.policy_templates_plugin.PolicyTemplatesForResourcePlugin: Instance of the plugin
     """
 
-    policy_templates = PolicyTemplatesProcessor.get_default_policy_templates_json()  # type: ignore[no-untyped-call]
-    processor = PolicyTemplatesProcessor(policy_templates)  # type: ignore[no-untyped-call]
+    policy_templates = PolicyTemplatesProcessor.get_default_policy_templates_json()
+    processor = PolicyTemplatesProcessor(policy_templates)
     return PolicyTemplatesForResourcePlugin(processor)  # type: ignore[no-untyped-call]
